/*
 *  Copyright (C) 2021 Texas Instruments Incorporated
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include <kernel/dpl/DebugP.h>
#include "ti_drivers_config.h"
#include "ti_drivers_open_close.h"
#include "ti_board_open_close.h"
#include <drivers/i2c.h>

/*
 * This is an empty project provided for all cores present in the device.
 * User can use this project to start their application by adding more SysConfig modules.
 *
 * This application does driver and board init and just prints the pass string on the console.
 * In case of the main core, the print is redirected to the UART console.
 * For all other cores, CCS prints are used.
 */

void empty_main(void *args)
{

    int32_t         status = SystemP_SUCCESS;
    I2C_Handle      i2cHandle;
    uint8_t buffer[2] = {0};

    /* STEP 1:
     *
     * Opening drivers, I2C being one of them.
     */
    Drivers_open();
    Board_driversOpen();

    /* STEP 2:
     *
     * Initializes I2C Handle.
     */
    i2cHandle = gI2cHandle[CONFIG_I2C0];

    /* STEP 3:
     *
     * Suppose our usecase is to set PIN number 16 to Output Mode, then we need to
     * write to Configuration Registers more specifically Configuration Port 1.
     * Configuration Port 1 is at 0x0D and the default value of this port is b"11111111"
     * We need to set the 6th bit to 0. So the value to write would be b"10111111" which is 0xBF.
     */
    buffer[0] = 0x0D;
    buffer[1] = 0xBF;

    I2C_Transaction i2cTransaction;
    I2C_Transaction_init(&i2cTransaction);
    i2cTransaction.targetAddress = 0x22;
    i2cTransaction.writeBuf = buffer;
    i2cTransaction.writeCount = 2;
    status = I2C_transfer(i2cHandle, &i2cTransaction);
    DebugP_assert(SystemP_SUCCESS == status);


    Board_driversClose();
    Drivers_close();
}
